@@ -20,11 +20,20 @@
 #include "notes.h"
 #include "notes_icons.h"
 
+#define MARGIN 4
+
 gboolean title_changing = FALSE;
 
 /* definied in notes_applet.c */
 extern NoteApplet notes_applet;
 
+gboolean
+on_note_delete (void)
+{
+   /* prevent Alt-F4 from closing note */
+   return TRUE;
+}
+
 gboolean
 on_title_change(GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
@@ -181,6 +190,10 @@ notes_create_note(void)
     gtk_window_set_skip_pager_hint(GTK_WINDOW(main_w), TRUE);
     gtk_window_set_skip_taskbar_hint(GTK_WINDOW(main_w), TRUE);
 
+    /* prevent Alt-F4 from closing note */
+    g_signal_connect (main_w, "delete-event", G_CALLBACK (on_note_delete), 
+	              NULL);
+    
     /* vertical box */
     vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(main_w), vbox);
@@ -194,7 +207,10 @@ notes_create_note(void)
 
     /* textview */
     text_view = gtk_text_view_new();
-    gtk_box_pack_start(GTK_BOX(vbox), text_view, TRUE, TRUE, 1);
+    gtk_box_pack_start(GTK_BOX(vbox), text_view, TRUE, TRUE, 0);
+    g_object_set (G_OBJECT (text_view),
+	          "left-margin", MARGIN, "right-margin", MARGIN,
+		  NULL);
     gtk_widget_show(text_view);
     /* add to note structure */
     note->text_view = text_view;
