@@ -82,7 +82,6 @@ typedef struct __note_applet {
     gint panel_size;
 
     /* notes edited flag */
-    GTimer *notes_timer;
     gboolean notes_saved;
 
     /* user color */
@@ -92,6 +91,9 @@ typedef struct __note_applet {
     /* other options */
     gboolean notes_sticky;
     gboolean show_notes;
+
+    /* save timeout */
+    int save_id;
 } NoteApplet;
 
 
