@@ -21,7 +21,7 @@
 
 static void notes_free_note(Note *note);
 static void notes_free(Control *ctrl);
-static void notes_delete_note(GtkWidget *widget, gpointer data);
+static void notes_delete_note_help(GtkWidget *widget, gpointer data);
 static void notes_read_config(Control *ctrl, xmlNodePtr parent);
 static void notes_write_config(Control *ctrl, xmlNodePtr parent);
 static gboolean notes_control_new(Control *ctrl);
@@ -280,7 +280,11 @@ notes_load_config(void)
     error_str = g_malloc(sizeof(char) * 256);
 
     /* set config file name */
-    filename = xfce_get_userfile("notes.xml", NULL);
+    filename = xfce_resource_lookup (XFCE_RESOURCE_CONFIG,
+                                     "xfce4" G_DIR_SEPARATOR_S "notes.xml");
+    
+    if (!filename)
+        filename = xfce_get_userfile("notes.xml", NULL);
 
     if (!g_file_test(filename, G_FILE_TEST_EXISTS)) {
 	g_free(error_str);
@@ -347,7 +351,9 @@ notes_store_config(void)
     /* note info in config file */
     gchar x[5], y[5], w[5], h[5];
 
-    filename = xfce_get_userfile("notes.xml", NULL);
+    filename = xfce_resource_save_location (XFCE_RESOURCE_CONFIG,
+                                     "xfce4" G_DIR_SEPARATOR_S "notes.xml",
+                                     TRUE);
 
     list = g_list_first(notes_applet.notes);
     while (list != NULL) {
@@ -432,7 +438,6 @@ notes_note_changed(GtkEditable *editable, gpointer data)
 {
     /* set flag */
     notes_applet.notes_saved = FALSE;
-    g_timer_start(notes_applet.notes_timer);
     return;
 }
 
@@ -454,7 +459,7 @@ notes_new_note(void)
 
     /* connect close button on the note */
     g_signal_connect(G_OBJECT(note->close_button), "clicked",
-		     G_CALLBACK(notes_delete_note), (gpointer)note);
+		     G_CALLBACK(notes_delete_note_help), (gpointer)note);
     /* notify if something was changed */
     text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(note->text_view));
     g_signal_connect(G_OBJECT(text_buffer), "changed",
@@ -493,12 +498,12 @@ notes_free(Control *ctrl)
 {
     GList *cur;
     Note *note;
-    
-    g_return_if_fail(ctrl != NULL);
-    g_return_if_fail(ctrl->data != NULL);
 
     /* save notes */
     notes_store_config();
+    
+    g_return_if_fail(ctrl != NULL);
+    g_return_if_fail(ctrl->data != NULL);
 
     cur = g_list_first(notes_applet.notes);
     while (cur) {
@@ -512,27 +517,101 @@ notes_free(Control *ctrl)
     
 }
 
+void
+notes_delete_note(Note *note, GList *cur)
+{
+    notes_applet.notes = g_list_remove_link(notes_applet.notes, 
+					    cur);
+    notes_free_note(note);
+    g_list_free(cur);
+
+    /* set new tooltips */
+    notes_set_tooltips();
+    /* save notes */
+    notes_store_config();
+
+    return;
+}
+
 static void
-notes_delete_note(GtkWidget *widget, gpointer data)
+notes_delete_note_help(GtkWidget *widget, gpointer data)
 {
     GList *cur;
     Note *note, *note_user;
 
+    GtkWidget *dialog, *hbox, *dialog_label, *dialog_image;
+    GtkTextIter start, end;
+    GtkTextBuffer *buffer;
+    gchar *text;
+    gint dialog_response;
+
     note_user = (Note *)data;
 
     cur = g_list_first(notes_applet.notes);
     while (cur != NULL) {
 	note = cur->data;
-	/* we found it, remove it */
+	/* note found */
 	if (note->id == note_user->id) {
-	    notes_applet.notes = g_list_remove_link(notes_applet.notes, cur);
-	    notes_free_note(note);
-	    g_list_free(cur);
 
-	    /* set new tooltips */
-	    notes_set_tooltips();
+	    /* get text from note */
+	    buffer 
+		= gtk_text_view_get_buffer(GTK_TEXT_VIEW(note->text_view));
+	    gtk_text_buffer_get_bounds (buffer, &start, &end);
+	    text = gtk_text_iter_get_text (&start, &end);
 
-	    return;
+	    /* only as for confirmation if there is text in note */ 
+	    if (strlen(g_strstrip(text)) != 0) {
+
+		/* create dialog for delete confirmation */
+		dialog = 
+		    gtk_dialog_new_with_buttons("Delete Note?",
+						GTK_WINDOW(note->note_w),
+						GTK_DIALOG_MODAL |
+						GTK_DIALOG_NO_SEPARATOR,
+						GTK_STOCK_DELETE,
+						GTK_RESPONSE_ACCEPT,
+						GTK_STOCK_CANCEL,
+						GTK_RESPONSE_REJECT,
+						NULL);
+
+		/*
+		gtk_window_set_transient_for(GTK_WINDOW(dialog),
+					     GTK_WINDOW(note->note_w));
+		*/
+
+		hbox = gtk_hbox_new(FALSE, 0);
+		gtk_widget_show(hbox);
+		gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox),
+				  hbox);
+
+		dialog_image = 
+		    gtk_image_new_from_stock(GTK_STOCK_DIALOG_QUESTION,
+					     GTK_ICON_SIZE_DIALOG);
+		gtk_widget_show(dialog_image);
+		gtk_box_pack_start_defaults(GTK_BOX(hbox), dialog_image);
+
+		dialog_label = gtk_label_new("Really delete note?");
+		gtk_widget_show(dialog_label);
+		gtk_box_pack_start_defaults(GTK_BOX(hbox), dialog_label);
+
+		/* run the dialog */
+		dialog_response = gtk_dialog_run(GTK_DIALOG(dialog));
+		
+		if (dialog_response == GTK_RESPONSE_ACCEPT) {
+		    notes_delete_note(note, cur);
+		}
+		
+		gtk_widget_destroy(dialog);
+
+		/* we have done what we were set to do, leave */
+		return;
+	    } else {
+		/* delete the note without user interaction if the note 
+		   was empty */
+		notes_delete_note(note, cur);
+
+		return;
+	    }
 	}
 	cur = g_list_next(cur);
     }
@@ -620,6 +699,8 @@ notes_read_config(Control *ctrl, xmlNodePtr parent)
     /* do some updating */
     notes_update_visibility();
     notes_update_colors();
+    notes_update_sticky();
+
     /* set tooltips */
     notes_set_tooltips();
 
@@ -663,22 +744,22 @@ notes_attach_callback(Control *ctrl, const gchar *signal, GCallback cb,
 }
 
 void 
-notes_destroy_cb(GtkWidget *widget, gpointer data)
+notes_destroy_cb(GtkWidget *widget, NoteApplet *notes)
 {
-    gtk_widget_destroy(widget);
-    return;
+    if (notes->save_id > 0)
+    {
+        g_source_remove (notes->save_id);
+        notes->save_id = 0;
+    }
 }
 
 gboolean
 notes_save_notes_timeout(gpointer data)
 {
     if (notes_applet.notes_saved == FALSE) {
-	if (g_timer_elapsed(notes_applet.notes_timer, NULL) > 5.0) {
-	    notes_store_config();
-	    DBG("notes saved\n");
-	    notes_applet.notes_saved = TRUE;
-	    g_timer_stop(notes_applet.notes_timer);
-	}
+	notes_store_config();
+	DBG("notes saved\n");
+	notes_applet.notes_saved = TRUE;
     }
     /* return tree to keep timeout active */
     return TRUE;
@@ -731,17 +812,17 @@ notes_control_new(Control *ctrl)
     /* make a default user color, yellow */
     gdk_color_parse("yellow", &notes_applet.note_color);
 
-    /* create a timer */
-    notes_applet.notes_timer = g_timer_new();
-
     /* create a root elmt  */
     notes_applet.doc = xmlNewDoc("1.0");
     xmlptr = xmlNewNode(NULL, "notes");
     xmlDocSetRootElement(notes_applet.doc, xmlptr);
 
+    /* initialize tooltips */
+    notes_set_tooltips();
+
     /* add timeout to save notes if required */
-    /* call notes_save_notes_timeout every 2 seconds */
-    g_timeout_add(5000, notes_save_notes_timeout, NULL);
+    /* call notes_save_notes_timeout every 5 seconds */
+    notes_applet.save_id = g_timeout_add(5000, notes_save_notes_timeout, NULL);
 
     gtk_widget_set_size_request(ctrl->base, -1, -1);
 
@@ -761,7 +842,7 @@ notes_set_size(Control *ctrl, int size)
 
     g_object_ref(notes_applet.event_box);
     gtk_container_foreach(GTK_CONTAINER(notes_applet.event_box),
-			  (GtkCallback)notes_destroy_cb, NULL);
+			  (GtkCallback)notes_destroy_cb, &notes_applet);
     
     pix = gdk_pixbuf_copy(notes_applet.pixbuf);
     pix = gdk_pixbuf_scale_simple(pix, dim, dim, GDK_INTERP_BILINEAR);
